# -*- coding: utf-8 -*-
"""
Script to recreate Figure 1 in manuscript:
Rarest Rainfall extremes will see the greatest relative increase in magnitude 
under future climate change, in Nature Communications Earth and Environment (2022)
by Gaby Joanne Gruendemann, Nick van de Giesen, Lukas Brunner and Ruud van der Ent

@author: ggrundemann
"""

import numpy as np
import xarray as xr
import string
import matplotlib.pyplot as plt
import matplotlib.cm as cm
import cartopy.crs as ccrs
import cartopy.feature as cfeature

#%% directories

dir_files = '' # folder in which the files listed below are stored

#%% load data and mask

T100his = xr.open_dataset(dir_files + '/T100_MEV_weighted-mean-std-med-ipr_historical.nc')
T100585 = xr.open_dataset(dir_files + '/T100_MEV_weighted-mean-std-med-ipr_ssp585.nc')
maskdry = xr.open_dataset(dir_files + '/mask_dry_areas.nc')

maskdry = xr.open_dataset(dir_files + '/mask_dry_areas.nc')
maskdry = maskdry.mask.values
maskdry = maskdry.astype(float)
maskdry[maskdry == 0] = np.nan


lons, lats = np.meshgrid(T100his.lon,T100his.lat)
cmap = cm.RdBu 

dataa = T100his['mean'].values
datab = T100585['mean'].values

plotdata = [dataa, datab]

vmin = 0
vmax = 300


rlat = 720
rlon = 1440
locsy = [0.94,  0.465]
locsx = [0.025, 0.025]

size=12

titles = ['historical','SSP5-8.5']

#%% Figure 1 - T100 mean

fig = plt.figure(figsize=(size/2.54,size/2.54))
for i in range(0,2):
    print(i)
    ax  = fig.add_subplot(2,1,i+1, projection=ccrs.EckertIV())
    ax.set_global()
    ax.coastlines(linewidth=0.1)
    ax.add_feature(cfeature.BORDERS, linewidth=0.1)
    data = plotdata[i]
    data = data * maskdry
    datae = data[:,rlat:]
    dataw = data[:,:rlat]
    dataew = np.hstack((datae, dataw))
    dataplot = np.flipud(dataew)
    msk = ax.imshow(np.ones((720, 1440)), transform=ccrs.PlateCarree(), cmap=cm.gray_r, vmin=0, vmax=2)
    m = ax.imshow(dataplot,transform=ccrs.PlateCarree(), cmap=cm.viridis_r, vmin=0, vmax=300)
    plt.gcf().text(locsx[i], locsy[i], string.ascii_lowercase[i]+')',fontsize=8)
    plt.title(titles[i], fontsize=8)
plt.tight_layout()
cax = fig.add_axes([0.05, 0, 0.9, 0.01]) # [left, bottom, width, height]
cb = plt.colorbar(m, cax=cax,orientation='horizontal',extend='max',aspect=0.4)
cb.ax.tick_params(labelsize=8) 
cb.set_label('precipitation depth (mm/day)',fontsize=8)
plt.savefig('Fig_01.pdf', bbox_inches="tight", dpi=300)


#%% Figure S03
# datac = T100his['std'].values
# datad = T100585['std'].values

# plotdata = [datac, datad]#, datac, datad]

# vmin = 0
# vmax = 300
# titles = ['historical', 'SSP5-8.5']

# rlat = 720
# rlon = 1440
# locsy = [0.94,  0.465]
# locsx = [0.025, 0.025]

# size=12
# fig = plt.figure(figsize=(size/2.54,size/2.54))
# for i in range(0,2):
#     print(i)
#     ax  = fig.add_subplot(2,1,i+1, projection=ccrs.EckertIV())
#     ax.set_global()
#     ax.coastlines(linewidth=0.1)
#     ax.add_feature(cfeature.BORDERS, linewidth=0.1)
#     data = plotdata[i]
#     data = data * maskdry
#     datae = data[:,rlat:]
#     dataw = data[:,:rlat]
#     dataew = np.hstack((datae, dataw))
#     dataplot = np.flipud(dataew)
#     ax.imshow(np.ones((720, 1440)), transform=ccrs.PlateCarree(), cmap=cm.gray_r, vmin=0, vmax=2)
#     m = ax.imshow(dataplot,transform=ccrs.PlateCarree(), cmap=cm.viridis_r, vmin=0, vmax=300)
#     plt.gcf().text(locsx[i], locsy[i], string.ascii_lowercase[i]+')',fontsize=8)
#     plt.title(titles[i], fontsize=8)
# plt.tight_layout()
# cax = fig.add_axes([0.05, 0, 0.9, 0.01]) # [left, bottom, width, height]
# cb = plt.colorbar(m, cax=cax,orientation='horizontal',extend='max',aspect=0.4)
# cb.ax.tick_params(labelsize=8) 
# cb.set_label('precipitation depth (mm/day)',fontsize=8)
# plt.savefig('Sfig_03.pdf', bbox_inches="tight", dpi=300)

