# -*- coding: utf-8 -*-
"""
Script to recreate Figure 4 in manuscript:
Rarest Rainfall extremes will see the greatest relative increase in magnitude 
under future climate change, in Nature Communications Earth and Environment (2022)
by Gaby Joanne Gruendemann, Nick van de Giesen, Lukas Brunner and Ruud van der Ent

@author: ggrundemann
"""

import numpy as np
import xarray as xr
import matplotlib as mpl
import matplotlib.pyplot as plt
import matplotlib.cm as cm
import matplotlib.colors as mcolors
import string
import cartopy.crs as ccrs
import cartopy.feature as cfeature

#%% specify directories
dir_files = '' # folder in which the files listed below are stored

#%%
# dif   = xr.open_dataset(dir_files + '/difT100m-difT1q_mean-med-ipr_all_ssps_unweighted.nc') # unweighted
difw  = xr.open_dataset(dir_files + '/difT100m-difT1q_mean-med-ipr_all_ssps_weighted.nc') # weighted
hatch = xr.open_dataset(dir_files + '/hatching_difT100m-difT1q_ssps.nc') # file for hatching

maskdry = xr.open_dataset(dir_files + '/mask_dry_areas.nc')
maskdry = maskdry.mask.values
maskdry = maskdry.astype(float)
maskdry[maskdry == 0] = np.nan

#%%
def create_plot_cartopy_nr2_nc2(plotting, hatch, par='mean',hatching=True,
                                countries=True, savefig=True, 
                                savename='savename',pdf=False,dpi=100):
    ssp    = ['126', '245', '370', '585']
    titles   = ['SSP1-2.6', 'SSP2-4.5', 'SSP3-7.0', 'SSP5-8.5']
    fig    = plt.figure(figsize=(20/2.54,12/2.54))
    for i in range(0,4):
        ax  = fig.add_subplot(2,2,i+1, projection=ccrs.EckertIV())
        ax.set_global()
        ax.coastlines(linewidth=0.1)
        if countries == True:
            ax.add_feature(cfeature.BORDERS, linewidth=0.1)

        if par == 'median':
            ar = 'median_ssp' + ssp[i]
        elif par == 'mean':
            ar = 'mean_ssp' + ssp[i]


        data     = plotting[ar].values
        data     = data * maskdry # added for mask
        datae    = data[:,rlat:]
        dataw    = data[:,:rlat]
        dataew   = np.hstack((datae, dataw))
        dataplot = np.flipud(dataew)


        mhatch  = hatch['hatching_ssp'+ssp[i]].values
        mhatchplot  = mhatch * maskdry
        
        mp = np.ma.masked_not_equal(mhatchplot, 1)
        ax.imshow(np.ones((720, 1440)), transform=ccrs.PlateCarree(), cmap=cm.gray, vmin=0, vmax=2)

        m = ax.imshow(dataplot, transform=ccrs.PlateCarree(), cmap=cmap, vmin=vmin, vmax=vmax, norm=norm)
        if hatching == True:
            ax.contourf(lons, lats, mp, transform=ccrs.PlateCarree(), colors='none',hatches=['........']) 
        ax.set_title(titles[i], fontsize=8)
        plt.gcf().text(locsx[i], locsy[i], string.ascii_lowercase[i]+')',fontsize=8)
    cax = fig.add_axes([0.05, 0, 0.9, 0.01]) # [left, bottom, width, height]
    cb = plt.colorbar(m, cax=cax,orientation='horizontal',extend='both',aspect=0.4,ticks=lvls)
    cb.ax.tick_params(labelsize=8) 
    cb.set_label('change (%)',fontsize=8)
    plt.tight_layout()
    if savefig == True:
        plt.savefig(savename + '.pdf', dpi=dpi, bbox_inches="tight")
    return plt.show()
#%%
#%%
rlat = 720
rlon = 1440
mpl.rcParams['hatch.linewidth'] = 0.1

f           = lambda x: ((x+180) % 360) - 180
lat         = difw.lat.values
#lat         = np.sort(lat)[::-1]
lon         = difw.lon.values
lon         = f(lon)
ind         = np.argsort(lon)
lonm        = lon[ind]
lonsm, lats = np.meshgrid(lonm, difw.lat)
lons, lats  = np.meshgrid(difw.lon, difw.lat)


#%%
#%% FIGURE WITH DIFFERENCE T100 - DIFFERENCE T1


vmin = -50
vmax = 50

lvls = np.arange(vmin,vmax+1,10)
norm = mcolors.TwoSlopeNorm(vmin=vmin, vcenter=0., vmax=vmax)
cmap = cm.RdGy_r


locsy = [0.94,  0.94,  0.465, 0.465]
locsx = [0.025, 0.515, 0.025, 0.515]

savename = 'Fig_04.pdf'
create_plot_cartopy_nr2_nc2(difw, hatch, par='mean', countries=True, savefig=True, savename=savename, dpi=300)
# savename = 'Fig_04_unweighted.pdf'
# create_plot_cartopy_nr2_nc2(dif, hatch, par='mean', countries=True, savefig=True, savename=savename, dpi=300)


