# -*- coding: utf-8 -*-
"""
Script to recreate Table 1 in manuscript:
Rarest Rainfall extremes will see the greatest relative increase in magnitude 
under future climate change, in Nature Communications Earth and Environment (2022)
by Gaby Joanne Gruendemann, Nick van de Giesen, Lukas Brunner and Ruud van der Ent

@author: ggrundemann
"""


#%% load packages
import numpy as np
import pandas as pd
import xarray as xr
import regionmask

#%% specify directories
dir_files = '' # folder in which the files listed below are stored

#%% open dataset
difw    = xr.open_dataset(dir_files + '/difT100m-difT1q_mean-med-ipr_all_ssps_weighted.nc') # weighted

maskdry = xr.open_dataset(dir_files + '/mask_dry_areas.nc')
maskdry = maskdry.mask.values
maskdry = maskdry.astype(float)
maskdry[maskdry == 0] = np.nan

difwm   = difw * maskdry

#%% create regional mask in 3D for all IPCC WGI reference regions (version 4)
ar6_all = regionmask.defined_regions.ar6.all
mask_3D = ar6_all.mask_3D(difwm)

#%% create mask for all land regions
land_110  = regionmask.defined_regions.natural_earth.land_110
land_mask = land_110.mask_3D(difwm)

#%%
weights = np.cos(np.deg2rad(difwm.lat))

dsreg   = difwm.weighted(mask_3D   * weights).mean(dim=("lat", "lon"))
dslnd   = difwm.weighted(land_mask * weights).mean(dim=("lat", "lon"))
dsall   = difwm.weighted(weights).mean(dim=("lat", "lon"))

#%%
list_abbrevs    = []
list_names      = []
list_ssp        = []
list_126        = []
list_245        = []
list_370        = []
list_585        = []
for rno in range(len(mask_3D.region.values)+2):
    for ssp in ['ssp126','ssp245','ssp370','ssp585']:
        if rno < 58:
            mean = dsreg['mean_'+ssp].isel(region=rno).values
        elif rno == 58:
            mean = dslnd['mean_'+ssp].isel(region=0).values
        elif rno == 59:
            mean = dsall['mean_'+ssp].values
        if ssp == 'ssp126':
            list_126.append(mean)
        elif ssp == 'ssp245':
            list_245.append(mean)
        elif ssp == 'ssp370':
            list_370.append(mean)
        elif ssp == 'ssp585':
            list_585.append(mean)
    if rno < 58:
    if rno < 58:
        list_abbrevs.append(ar6_all[rno].abbrev)
        list_names.append(ar6_all[rno].name)
    elif rno == 58:
        list_abbrevs.append('GLD')
        list_names.append('Global.land')
    elif rno == 59:
        list_abbrevs.append('GAL')
        list_names.append('Global.all')

df = pd.DataFrame()
df['Abbreviation'] = list_abbrevs
df['Region']       = list_names
df['SSP1-2.6']     = list_126
df['SSP2-4.5']     = list_245
df['SSP3-7.0']     = list_370
df['SSP5-8.5']     = list_585
''' copy to excel, sort by SSP5-8.5, use something like https://www.tablesgenerator.com/# to copy excel to latex format '''